@@ -1,21 +1,18 @@
-import responses
-import requests
+import httpx
+import respx
 
-from wapitiCore.net.crawler import Page
+from wapitiCore.net.crawler import Response
+from wapitiCore.parsers.html_parser import Html
 
 
-@responses.activate
+@respx.mock
 def test_formactions():
     with open("tests/data/formactions.html") as form_action:
         url = "http://perdu.com/"
-        responses.add(
-            responses.GET,
-            url,
-            body=form_action.read()
-        )
+        respx.get(url).mock(return_value=httpx.Response(200, text=form_action.read()))
 
-        resp = requests.get(url, allow_redirects=False)
-        page = Page(resp)
+        resp = httpx.get(url, follow_redirects=False)
+        page = Html(Response(resp).content, url)
         count = 0
 
         for form in page.iter_forms():
